/*
 * Copyright (C) 2014 OpenSIPS Solutions
 *
 * This file is part of opensips, a free SIP server.
 *
 * opensips is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * opensips is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 *
 * history:
 * ---------
 *  2014-08-xx  created (vlad-paiu)
 */

#ifndef _UAC_UAC_AUTH_H_
#define _UAC_UAC_AUTH_H_

#include "../../parser/msg_parser.h"
#include "../rr/api.h"

void rr_uac_auth_checker(struct sip_msg *msg, str *r_param, void *cb_param);
int uac_inc_cseq(struct sip_msg *msg, int val);

#endif
